@@ -32,8 +32,27 @@ export default class EditController extends Controller {
     );
   }
 
+  // Forwarders replacing route-action helper usage
   @action
-  delete(item) {
+  onCreate(item, event) {
+    event?.preventDefault();
+    this.target.send('create', item, event);
+  }
+
+  @action
+  onUpdate(item, event) {
+    event?.preventDefault();
+    this.target.send('update', item, event);
+  }
+
+  @action
+  onCancel(item, event) {
+    event?.preventDefault();
+    this.target.send('cancel', item, event);
+  }
+
+  @action
+  onDelete(item) {
     this.target.send('delete', item);
   }
 }
